@@ -4,6 +4,7 @@ Installation of the TOPP OpenCore environment.
 
 from fassembler import tasks
 from fassembler.project import Project, Setting
+from fassembler.util import asbool
 from glob import glob
 from time import sleep
 from xml.dom import minidom
@@ -429,11 +430,16 @@ class RunZopectlScript(tasks.Task):
 
 class RunZopeScriptsWithZeo(tasks.Task):
 
-    description = "Start zeo, run all zopectl scripts, stop zeo"
+    description = """
+    {{if task.skip_zopectl_scripts()}}Not trying to start zeo and run zopectl scripts, because skip_zopectl_scripts was set{{else}}Start zeo, run all zopectl scripts, stop zeo{{endif}}
+    """
 
     script_path = interpolated('script_path')
     script_args = interpolated('script_args')
 
+    def skip_zopectl_scripts(self):
+        return asbool(self.interpolate("{{config.skip_zopectl_scripts}}"))
+
     def __init__(self, *subtasks, **kw):
         stacklevel = kw.get('stacklevel', 1)
         super(RunZopeScriptsWithZeo, self).__init__(self.description,
@@ -463,6 +469,10 @@ class RunZopeScriptsWithZeo(tasks.Task):
             self._bind_tasks(subtask, *args, **kw)
 
     def run(self):
+        if self.skip_zopectl_scripts():
+            self.logger.notify("Not running zopectl scripts because skip_zopectl_scripts was specified")
+            return
+
         self.start_zeo()
         try:
             for task in self.subtasks:
@@ -631,6 +641,8 @@ class OpenCoreBase(Project):
     def get_req_setting(self, setting):
         return self.req_settings.get(setting, self.interpolate(self.defaults[setting]))
 
+    def run_clockserver(self):
+        return True
 
 class OpenCoreProject(OpenCoreBase):
     """
@@ -859,6 +871,12 @@ class ZEOProject(OpenCoreBase):
     spec_filename = 'opencore'  # Re-use opencore-req.txt.
 
     settings = [
+        Setting('skip_zopectl_scripts',
+                default='0',
+                help="If set, will not start ZEO nor run zopectl scripts;"
+                "useful if you already have another ZEO instance running "
+                "and you know your database is fully set up "
+                "(i.e. when building an upgrade in parallel to a running site)"),
         Setting('zeo_instance',
                 default='{{project.build_properties["virtualenv_path"]}}/zeo',
                 help='Instance home for ZEO'),
@@ -959,6 +977,12 @@ class MaildropProject(OpenCoreBase):
     title = 'Setup maildrop'
 
     settings = [
+        Setting('skip_zopectl_scripts',
+                default='0',
+                help="If set, will not start ZEO nor run zopectl scripts; "
+                "useful if you already have another ZEO instance running "
+                "and you know your database is fully set up "
+                "(i.e. when building an upgrade in parallel to a running site)"),
         Setting('smtp_host',
                 default='localhost',
                 help='Host to send mail to'),
@@ -1086,6 +1110,18 @@ class ExtraZopeProject(OpenCoreProject):
     Install an additional Zope instance
     """
 
+    def run_clockserver(self):
+        """
+        If this is set to True, the generated
+        zope.conf will include opencore's
+        clockserver directives. Since we only
+        need to run them from one Zope instance,
+        the default behavior is to run them on
+        the primary Zope instance and to disable
+        them on additional Zopes that are built.
+        """
+        return asbool(self.interpolate("{{config.run_clockserver}}"))
+
     name = "opencore-zope"
     title = "Install Zope client"
 
@@ -1100,6 +1136,9 @@ exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}
 """
 
     settings = [
+        Setting('run_clockserver',
+                default='0',
+                help="Whether to set up OpenCore's ClockServer directives in this Zope instance's zope.conf"),
         Setting('zope_num',
                 default='1',
                 help='Numerical index for this zope (i.e. len(number_of_zopes) -- used by default in calculating other settings, like the directory to install this zope into and what port it should run on'),
@@ -1159,6 +1198,10 @@ exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}
 
     actions = [
         tasks.VirtualEnv(path='opencore', never_create_virtualenv=True),
+
+        tasks.EnsureDir('Create zope instance var/ directory',
+                        '{{env.var}}/opencore-{{config.zope_instance_name}}'),
+
         tasks.CopyDir('Create custom skel',
                       skel_dir,
                       'opencore/src/Zope/custom_skel_{{config.zope_instance_name}}'),
@@ -1179,9 +1222,6 @@ exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}
                       dest='{{env.base_path}}/etc/opencore/{{config.zope_instance_name}}_etc',
                       add_dest_to_svn=True),
 
-        #tasks.EnsureDir('Make sure new Zope configuration exists and is checked in to SVN',
-        #                dest='{{env.base_path}}/etc/opencore/{{config.zope_instance_name}}_etc',
-        #                svn_add=True),
 
         SymlinkExtraZopeConfig('Install Zope configuration symlink',
                                source='{{env.base_path}}/etc/opencore/{{config.zope_instance_name}}_etc'),
@@ -1192,5 +1232,11 @@ exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}
                          svn_add=True, executable=True, overwrite=True),
 
         tasks.InstallSupervisorConfig(script_name="opencore-{{config.zope_instance_name}}"),
+
+        tasks.Script('zinstall zcmlloader into package-includes',
+                     ['{{config.virtualenv_path}}/bin/python', 'setup.py',
+                      'zinstall', 
+                      '{{env.base_path}}/opencore/{{config.zope_instance_name}}'],
+                     cwd='{{env.base_path}}/opencore/src/zcmlloader'),
         
         ]
